@@ -152,7 +152,7 @@ class LaharFlowData(object):
             
         if zipped:
             infoFilePath = _path_of_file_in_zip('RunInfo.txt',self._zipref)[0]
-            infoFile = self._zipref.extract(infoFilePath,path=self.dir)
+            infoFile = self._zipref.extract(infoFilePath) #,path=self.dir)
         else:
             infoFile = os.path.join(LaharFlowDir,"RunInfo.txt")
             assert(os.path.isfile(infoFile)), 'Run info file {} does not exist'.format(infoFile)
@@ -265,7 +265,8 @@ class LaharFlowData(object):
             self.get_nc_files()
             self.get_tar_files()
             self.get_gz_files()
-            self.get_tiff_files()
+            if not self.zipped:
+                self.get_tiff_files()
 
             self.clatlong = [self.clat,self.clong]
 
@@ -635,6 +636,8 @@ class LaharFlowData(object):
                 filetype = 'MaxHeights.txt'
             elif filename=='MaxSpeeds.txt':
                 filetype = 'MaxSpeeds.txt'
+            elif filename=='InundationTime.txt':
+                filetype = 'InundationTime.txt'
             if filename=='Maximums.nc':
                 filetype = 'Maximums.nc'
             else:
@@ -695,7 +698,7 @@ class LaharFlowData(object):
             data = np.genfromtxt(LaharFlowFile, delimiter=',', names=True, usecols=cols)
             return data
         except:
-            raise RuntimeWarning('Unable to get data from {}'.format(filename))
+            raise RuntimeWarning('Unable to get data from {}'.format(LaharFlowFile))
     
     def _get_data_nc(self, LaharFlowFile):
 
@@ -921,9 +924,10 @@ class LaharFlowData(object):
 
         # return raster
 
-    def _raster_flatten(raster):
-        rflat = raster.data.flatten()
-        return rflat[~np.isnan(rflat)]
+    def _raster_flatten(self, raster, var):
+        vals = raster[var].values.flatten()
+        rflat = vals[~np.isnan(vals)]    
+        return rflat
 
     def _get_data_column(self, filename, data_col):
 
@@ -1076,10 +1080,10 @@ class LaharFlowData(object):
         if 'maximum_depth' not in list(data.keys()):
             raise RuntimeError('maximum_depth not in data')
         
-        maxh = data['maximum_depth']
+        maxh = data[['maximum_depth']]
 
         if vmin is not None:
-            maxh = maxh.where(maxh.data>vmin)
+            maxh = maxh.where(maxh>vmin, drop=True)
 
         return maxh
 
@@ -1110,12 +1114,12 @@ class LaharFlowData(object):
                 data = self.raster('MaxSpeeds.txt')
             
         if 'maximum_speed' not in list(data.keys()):
-            raise RuntimeError('maximum_depth not in data')
+            raise RuntimeError('maximum_speed not in data')
 
-        maxspd = data['maximum_speed']
+        maxspd = data[['maximum_speed']]
 
         if vmin is not None:
-            maxspd = maxspd.where(maxspd.data>vmin)
+            maxspd = maxspd.where(maxspd>vmin, drop=True)
 
         return maxspd
     
@@ -1126,10 +1130,10 @@ class LaharFlowData(object):
             data = self.raster('InundationTime.txt')
         if 'inundation_time' not in list(data.keys()):
             data = self.raster('InundationTime.txt')
-        itime = data['inundation_time']
+        itime = data[['inundation_time']]
 
         if vmin is not None:
-            itime = itime.where(itime.data>vmin)
+            itime =itime.where(itime>vmin, drop=True)
         
         return itime
 
@@ -1248,17 +1252,16 @@ class LaharFlowData(object):
         
         return g
 
-    def max_depth_contours(self, data=None, name='MaxHeights', cntrs=0.1, vmin=0.1):
+    def max_depth_contours(self, data=None, var='maximum_depth', cntrs=0.1, vmin=0.1):
         
         maxh = self.max_depth(data=data, vmin=vmin)
 
         if maxh is not None:
-            #maxh = maxh['maximum_depth']
             if type(cntrs)==np.ndarray:
                 cntrs = cntrs.tolist()
             else:
                 if cntrs=='Jenks':
-                    cntrs = jenkspy.jenks_breaks(self._raster_flatten(maxh), nb_class=10)
+                    cntrs = jenkspy.jenks_breaks(self._raster_flatten(maxh, var), nb_class=10)
                     cntrs = [c for c in cntrs if c>=vmin]
                     cntrs = cntrs[:-1]
                 if type(cntrs) is not list:
@@ -1266,7 +1269,7 @@ class LaharFlowData(object):
             
             cntrs.sort()
         
-            g = self._raster_contour(maxh, name, cntrs)
+            g = self._raster_contour(maxh, var, cntrs)
             return g
         else:
             return None
@@ -1362,27 +1365,26 @@ class LaharFlowData(object):
 
         if filename is not None:
             data = self._get_data(filename)
-
-        POI_xy = np.array(EastingNorthing_TM(self.clatlong, (lat, lon)))*1e3
+        POI_xy = np.array((self.clatlong, (lat, lon)))*1e3
 
         indx = np.sqrt((data['x_distance']-POI_xy[0])**2+(data['y_distance']-POI_xy[1])**2)<buffer
         
-        n = np.count_nonzero(indx)
+        # n = np.count_nonzero(indx)
 
-        dt = [
-            ('x_distance', np.float64),
-            ('y_distance', np.float64),
-            ('latitude', np.float64),
-            ('longitude', np.float64),
-            (var, np.float64)]
+        # dt = [
+        #     ('x_distance', np.float64),
+        #     ('y_distance', np.float64),
+        #     ('latitude', np.float64),
+        #     ('longitude', np.float64),
+        #     (var, np.float64)]
 
-        data_clipped = np.full((n), np.nan, dtype=dt)
+        # data_clipped = np.full((n), np.nan, dtype=dt)
 
-        data_clipped[var] = data[var][indx]
-        data_clipped['x_distance'] = data['x_distance'][indx]
-        data_clipped['y_distance'] = data['y_distance'][indx]
-        data_clipped['latitude'] = data['latitude'][indx]
-        data_clipped['longitude'] = data['longitude'][indx]
+        data_clipped = data[var][indx]
+        # data_clipped['x_distance'] = data['x_distance'][indx]
+        # data_clipped['y_distance'] = data['y_distance'][indx]
+        # data_clipped['latitude'] = data['latitude'][indx]
+        # data_clipped['longitude'] = data['longitude'][indx]
         
         return data_clipped
     
